package com.ruoyi.rocketmq.mapper;

import java.util.List;
import com.ruoyi.rocketmq.domain.InitialHeartbeatListenLog;

/**
 * 心跳信息日志Mapper接口
 * 
 * @author gyt
 * @date 2025-09-08
 */
public interface InitialHeartbeatListenLogMapper 
{
    /**
     * 查询心跳信息日志
     * 
     * @param clientId 心跳信息日志主键
     * @return 心跳信息日志
     */
    public InitialHeartbeatListenLog selectInitialHeartbeatListenLogByClientId(String clientId);

    /**
     * 查询心跳信息日志列表
     * 
     * @param initialHeartbeatListenLog 心跳信息日志
     * @return 心跳信息日志集合
     */
    public List<InitialHeartbeatListenLog> selectInitialHeartbeatListenLogList(InitialHeartbeatListenLog initialHeartbeatListenLog);

    /**
     * 新增心跳信息日志
     * 
     * @param initialHeartbeatListenLog 心跳信息日志
     * @return 结果
     */
    public int insertInitialHeartbeatListenLog(InitialHeartbeatListenLog initialHeartbeatListenLog);

    /**
     * 修改心跳信息日志
     * 
     * @param initialHeartbeatListenLog 心跳信息日志
     * @return 结果
     */
    public int updateInitialHeartbeatListenLog(InitialHeartbeatListenLog initialHeartbeatListenLog);

    /**
     * 删除心跳信息日志
     * 
     * @param clientId 心跳信息日志主键
     * @return 结果
     */
    public int deleteInitialHeartbeatListenLogByClientId(String clientId);

    /**
     * 批量删除心跳信息日志
     * 
     * @param clientIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteInitialHeartbeatListenLogByClientIds(String[] clientIds);
}
