package com.ruoyi.rocketmq.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.rocketmq.domain.InitialHeartbeatListenLog;
import com.ruoyi.rocketmq.service.IInitialHeartbeatListenLogService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 心跳信息日志Controller
 * 
 * @author gyt
 * @date 2025-09-08
 */
@RestController
@RequestMapping("/log")
public class InitialHeartbeatListenLogController extends BaseController
{
    @Autowired
    private IInitialHeartbeatListenLogService initialHeartbeatListenLogService;

    /**
     * 查询心跳信息日志列表
     */
    @RequiresPermissions("rocketmq:log:list")
    @GetMapping("/list")
    public TableDataInfo list(InitialHeartbeatListenLog initialHeartbeatListenLog)
    {
        startPage();
        List<InitialHeartbeatListenLog> list = initialHeartbeatListenLogService.selectInitialHeartbeatListenLogList(initialHeartbeatListenLog);
        return getDataTable(list);
    }

    /**
     * 导出心跳信息日志列表
     */
    @RequiresPermissions("rocketmq:log:export")
    @Log(title = "心跳信息日志", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, InitialHeartbeatListenLog initialHeartbeatListenLog)
    {
        List<InitialHeartbeatListenLog> list = initialHeartbeatListenLogService.selectInitialHeartbeatListenLogList(initialHeartbeatListenLog);
        ExcelUtil<InitialHeartbeatListenLog> util = new ExcelUtil<InitialHeartbeatListenLog>(InitialHeartbeatListenLog.class);
        util.exportExcel(response, list, "心跳信息日志数据");
    }

    /**
     * 获取心跳信息日志详细信息
     */
    @RequiresPermissions("rocketmq:log:query")
    @GetMapping(value = "/{clientId}")
    public AjaxResult getInfo(@PathVariable("clientId") String clientId)
    {
        return success(initialHeartbeatListenLogService.selectInitialHeartbeatListenLogByClientId(clientId));
    }

    /**
     * 新增心跳信息日志
     */
    @RequiresPermissions("rocketmq:log:add")
    @Log(title = "心跳信息日志", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody InitialHeartbeatListenLog initialHeartbeatListenLog)
    {
        return toAjax(initialHeartbeatListenLogService.insertInitialHeartbeatListenLog(initialHeartbeatListenLog));
    }

    /**
     * 修改心跳信息日志
     */
    @RequiresPermissions("rocketmq:log:edit")
    @Log(title = "心跳信息日志", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody InitialHeartbeatListenLog initialHeartbeatListenLog)
    {
        return toAjax(initialHeartbeatListenLogService.updateInitialHeartbeatListenLog(initialHeartbeatListenLog));
    }

    /**
     * 删除心跳信息日志
     */
    @RequiresPermissions("rocketmq:log:remove")
    @Log(title = "心跳信息日志", businessType = BusinessType.DELETE)
	@DeleteMapping("/{clientIds}")
    public AjaxResult remove(@PathVariable String[] clientIds)
    {
        return toAjax(initialHeartbeatListenLogService.deleteInitialHeartbeatListenLogByClientIds(clientIds));
    }
}
